@@ -12,9 +12,9 @@ def estimate_alpha_cf(
     Estimate alpha from an input image and an input trimap using Closed-Form Alpha Matting as proposed by :cite:`levin2007closed`.
 
     Parameters
-    -----------------
+    ----------
     image: numpy.ndarray
-        Image with shape :math:`h \\times  w \\times d` for which the foreground should be estimated
+        Image with shape :math:`h \\times  w \\times d` for which the alpha matte should be estimated
     trimap: numpy.ndarray
         Trimap with shape :math:`h \\times  w \\times 1` of the image
     preconditioner: function or scipy.sparse.linalg.LinearOperator
@@ -22,12 +22,23 @@ def estimate_alpha_cf(
     laplacian_kwargs: dictionary
         Arguments passed to the :code:`cf_laplacian` function
     cg_kwargs: dictionary
-        Arguments passed to the :code:`cg`
+        Arguments passed to the :code:`cg` solver
 
     Returns
-    ----------------
+    -------
     alpha: numpy.ndarray
         Estimated alpha matte
+
+    Example
+    -------
+    >>> from pymatting import *
+    >>> image = load_image("data/lemur/lemur.png", "RGB")
+    >>> trimap = load_image("data/lemur/lemur_trimap.png", "GRAY")
+    >>> alpha = estimate_alpha_cf(
+    ...     image,
+    ...     trimap,
+    ...     laplacian_kwargs={"epsilon": 1e-6},
+    ...     cg_kwargs={"maxiter":2000})
     """
     if preconditioner is None:
         preconditioner = ichol
