@@ -6,23 +6,35 @@ import numpy as np
 
 def estimate_alpha_lkm(image, trimap, laplacian_kwargs={}, cg_kwargs={}):
     """
-    Estimate alpha from an input image and an input trimap using Learning Based Digital Matting as proposed by :cite:`he2010fast`.
+    Estimate alpha from an input image and an input trimap as described in Fast Matting Using Large Kernel Matting Laplacian Matrices by :cite:`he2010fast`.
 
     Parameters
-    -----------------
+    ----------
     image: numpy.ndarray
-        Image with shape :math:`h \\times  w \\times d` for which the foreground should be estimated
+        Image with shape :math:`h \\times  w \\times d` for which the alpha matte should be estimated
     trimap: numpy.ndarray
         Trimap with shape :math:`h \\times  w \\times 1` of the image
     laplacian_kwargs: dictionary
         Arguments passed to the :code:`lkm_laplacian` function
     cg_kwargs: dictionary
-        Arguments passed to the :code:`cg`
+        Arguments passed to the :code:`cg` solver
 
     Returns
-    ----------------
+    -------
     alpha: numpy.ndarray
         Estimated alpha matte
+
+    Example
+    -------
+    >>> from pymatting import *
+    >>> image = load_image("data/lemur/lemur.png", "RGB")
+    >>> trimap = load_image("data/lemur/lemur_trimap.png", "GRAY")
+    >>> alpha = estimate_alpha_lkm(
+    ...     image,
+    ...     trimap,
+    ...     laplacian_kwargs={"epsilon": 1e-6, "radius": 15},
+    ...     cg_kwargs={"maxiter":2000})
+
     """
     L_matvec, diag_L = lkm_laplacian(image, **laplacian_kwargs)
 
